@@ -1,9 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "alt-codes" "0.0.5"
+(define-package "alt-codes" "20250101.1002"
   "Insert alt codes using meta key."
-  '((emacs "24.4"))
+  '((emacs "26.1"))
   :url "https://github.com/jcs-elpa/alt-codes"
-  :commit "b36c2b2bccc628da1579016381d5c3195c9e12b2"
-  :revdesc "b36c2b2bccc6"
+  :commit "24e3740f88c29efda5c4791720a55c4c548b1ed8"
+  :revdesc "24e3740f88c2"
+  :keywords '("convenience" "alt" "codes" "insertion" "meta")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
